@@ -1,8 +1,9 @@
+use 5.010_001;
 use strict;
 use warnings;
 
 package DBIx::Squirrel;
-$DBIx::Squirrel::VERSION = '1.3.3';
+$DBIx::Squirrel::VERSION = '1.3.4';
 =pod
 
 =encoding UTF-8
@@ -13,7 +14,7 @@ DBIx::Squirrel - A C<DBI> extension
 
 =head1 VERSION
 
-version 1.3.3
+version 1.3.4
 
 =cut
 
@@ -48,7 +49,7 @@ BEGIN {
     *DBIx::Squirrel::NORMALIZE_SQL                = *DBIx::Squirrel::util::NORMALISE_SQL;
 
     unless (defined $DBIx::Squirrel::VERSION) {
-        my $v = "1.3.3";
+        my $v = "1.3.4";
         *DBIx::Squirrel::VERSION = \$v;
     }
 }
@@ -67,7 +68,7 @@ sub _partition_imports_into_helpers_and_dbi_imports {
             shift;
             if (ref($_[0])) {
                 if (UNIVERSAL::isa($_[0], 'ARRAY')) {
-                    push @helpers, @{shift()};
+                    push @helpers, @{+shift};
                 }
                 else {
                     shift;
