@@ -7,10 +7,11 @@ package    # hide from PAUSE
 BEGIN {
     require DBIx::Squirrel
       unless defined($DBIx::Squirrel::VERSION);
+    require Exporter;
     $DBIx::Squirrel::Transform::JSON::Syck::VERSION   = $DBIx::Squirrel::VERSION;
     @DBIx::Squirrel::Transform::JSON::Syck::ISA       = qw/Exporter/;
-    @DBIx::Squirrel::Transform::JSON::Syck::EXPORT    = qw/as_json/;
     @DBIx::Squirrel::Transform::JSON::Syck::EXPORT_OK = qw/as_json/;
+    @DBIx::Squirrel::Transform::JSON::Syck::EXPORT    = @DBIx::Squirrel::Transform::JSON::Syck::EXPORT_OK;
 }
 
 use JSON::Syck;
@@ -20,7 +21,7 @@ sub as_json {
         local($JSON::Syck::ImplicitTyping)  = !!1;
         local($JSON::Syck::ImplicitUnicode) = !!1;
         local($JSON::Syck::SortKeys)        = !!1;
-        return JSON::Syck::Dump(shift);
+        return JSON::Syck::Dump(@_);
     };
 }
 
