@@ -1,4 +1,4 @@
-use diagnostics;
+use 5.010_001;
 use strict;
 use warnings;
 
